# Authors

The following individuals have contributed to the development and maintenance of the `chronostring` library.

## Core Contributors

- *Jean-Marie Favreau* jeanmarie.favreau@free.fr — Project lead, architecture, token system, date/time parsing engine

## Special thanks

Special thanks to the [Pommes de Lune](https://pommesdelune.fr) community and for the insightful discussions on *Mastodon* that helped define and refine the core functionalities of `chronostring`.
